@@ -1,5 +1,5 @@
 ###########################################################################
-# Copyright 2009 Nobody                                                   #
+# Copyright 2009 Michael Schweinberger                                    #
 #                                                                         #
 # This file is part of hergm.                                             #
 #                                                                         # 
@@ -131,6 +131,7 @@ InitErgmTerm.edges_i <- function(nw, arglist, ...) # Michael
   termnumber <- 1 + length(nw$terms)
   #print("InitErgmTerm.edges_i")
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print("number")
   #print(number)
   if (is.null(a$indicator)) 
@@ -147,7 +148,7 @@ InitErgmTerm.edges_i <- function(nw, arglist, ...) # Michael
     }
   else theta <- a$theta
   #print(theta)
-  list(name = "edges_i", coef.names="edges_i", 
+  list(name = "edges_i", coef.names = "edges_i", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE)
   #print(nw$terms[[termnumber]])
@@ -168,11 +169,12 @@ InitErgmTerm.arcs_i <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "arcs_i", coef.names="arcs_i", 
+  list(name = "arcs_i", coef.names = "arcs_i", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE)
   #print(nw$terms[[termnumber]])
@@ -193,11 +195,12 @@ InitErgmTerm.arcs_j <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "arcs_j", coef.names="arcs_j", 
+  list(name = "arcs_j", coef.names = "arcs_j", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE)
   #print(nw$terms[[termnumber]])
@@ -218,11 +221,12 @@ InitErgmTerm.edges_ij <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0
   #print(theta)
-  list(name = "edges_ij", coef.names="edges_ij",
+  list(name = "edges_ij", coef.names = "edges_ij",
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE)
   #print(nw$terms[[termnumber]])
@@ -243,11 +247,12 @@ InitErgmTerm.mutual_i <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "mutual_i", coef.names="mutual_i", 
+  list(name = "mutual_i", coef.names = "mutual_i", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE) 
   #print(nw$terms[[termnumber]])
@@ -268,16 +273,44 @@ InitErgmTerm.mutual_ij <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "mutual_ij", coef.names="mutual_ij", 
+  list(name = "mutual_ij", coef.names = "mutual_ij", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = FALSE) 
   #print(nw$terms[[termnumber]])
 }
 
+#########################################################
+InitErgmTerm.transitiveties_ijk <- function(nw, arglist, ...) # Michael
+{
+  n <- nw$gal$n # Number of nodes
+  #print("InitErgmTerm.transitiveties_ijk")
+  a <- check.ErgmTerm(nw, arglist, directed=TRUE, bipartite=FALSE,
+    varnames = c("number", "indicator", "theta"),
+    vartypes = c("numeric", "numeric", "numeric"),
+    defaultvalues = list(NULL, NULL, NULL),
+    required = c(FALSE, FALSE, FALSE))
+  termnumber <- 1 + length(nw$terms)
+  #print("InitErgmTerm.transitiveties_ijk")
+  indicator <- vector(mode = "numeric", length = n) # Category indicators  
+  for (i in 1:length(indicator)) indicator[i] <- 1
+  #print(indicator)
+  number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
+  # print(number)
+  theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
+  for (i in 1:length(theta)) theta[i] <- 0
+  #print(theta)
+  list(name = "transitiveties_ijk", coef.names = "transitiveties_ijk",
+                                inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
+                                dependence = TRUE)
+  #print(nw$terms[[termnumber]])
+}
+
 ######################################################### 
 InitErgmTerm.triangle_ijk <- function(nw, arglist, ...) # Michael 
 {
@@ -294,11 +327,12 @@ InitErgmTerm.triangle_ijk <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "triangle_ijk", coef.names="triangle_ijk", 
+  list(name = "triangle_ijk", coef.names = "triangle_ijk", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = TRUE)
   #print(nw$terms[[termnumber]])
@@ -319,11 +353,12 @@ InitErgmTerm.ttriple_ijk <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "ttriple_ijk", coef.names="ttriple_ijk", 
+  list(name = "ttriple_ijk", coef.names = "ttriple_ijk", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = TRUE)
   #print(nw$terms[[termnumber]])
@@ -344,11 +379,12 @@ InitErgmTerm.ctriple_ijk <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "ctriple_ijk", coef.names="ctriple_ijk", 
+  list(name = "ctriple_ijk", coef.names = "ctriple_ijk", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = TRUE)
   #print(nw$terms[[termnumber]])
@@ -369,11 +405,12 @@ InitErgmTerm.twostar_ijk <- function(nw, arglist, ...) # Michael
   for (i in 1:length(indicator)) indicator[i] <- 1
   #print(indicator)
   number <- nw$max_number # (Maximum) number of categories
+  if (is.null(number)) number <- 1 # (Maximum) number of categories
   #print(number)
   theta <- vector(mode = "numeric", length = number + 1) # Within- and between-category parameters
   for (i in 1:length(theta)) theta[i] <- 0 
   #print(theta)
-  list(name = "twostar_ijk", coef.names="twostar_ijk", 
+  list(name = "twostar_ijk", coef.names = "twostar_ijk", 
                                 inputs = c(0, 1, 1+length(indicator)+length(theta), c(number, indicator, theta)),
                                 dependence = TRUE)
   #print(nw$terms[[termnumber]])
